# CAT: A git-based system for running AI agents

Hello there! 

Would you like to have agents running as background processes on your repos?

Unlike other agents, your cat agents run indefinitely and only stop when they hit a token limit or time limit. 

A cat agent uses your git history as context to choose its next steps. 

Inspired by Linux and git, this is cat. Cat can mean:

- Computer Assisted Taskrunner
- Cute AI Toolkit
- a feline animal
- whatever you'd like it to mean

Caution: cat agents runs completely locally so treat your agent nicely and don't let them run away 🐈
 
## Getting started with this repo

Make sure you have pixi installed.
